( function( $ ) {
	'use strict';

	/**
	 * Remove the capacity to sort meta boxes if class `.not-sortable` is included.
	 *
	 * @see     https://wordpress.stackexchange.com/a/73806/85404
	 * @since   2.0.0
	 */
	$( window ).on( 'load', function() {
		$( '.meta-box-sortables' )
		// define the cancel option of sortable to ignore sortable element
		// for boxes with '.not-sortable' css class
		.sortable( 'option', 'cancel', '.boldermail-postbox.not-sortable .hndle, :input, button' )
		// and then refresh the instance
		.sortable( 'refresh' );
	} );

	/**
	 * Initialize help tips.
	 *
	 * @since   1.6.0
	 */
	$( document ).on( 'init_tooltips', function() {
		$( '.boldermail-tips, .boldermail-help-tip' ).tipTip( {
			'attribute': 'data-tip',
			'fadeIn': 50,
			'fadeOut': 50,
			'delay': 200
		} );
	} ).trigger( 'init_tooltips' );

	/**
	 * Select2 support.
	 *
	 * @since   1.5.0
	 */
	$( document ).on( 'boldermail-init-select2', function() {
		$( '.boldermail-select2' ).each( function() {
			const placeholder = $( this ).data( 'placeholder' );

			$( this ).select2( {
				placeholder: placeholder,
				width: '75%',
			} );
		} );
	} ).trigger( 'boldermail-init-select2' );

	/**
	 * Display a panel based on the tab selection.
	 *
	 * @since   1.0.0
	 */
	$( document ).on( 'boldermail-init-tabbed-panels', function() {
		$( 'ul.boldermail-tabs' ).show();

		$( 'ul.boldermail-tabs a' ).on( 'click', function( e ) {
			e.preventDefault();
			const panelWrap = $( this ).closest( 'div.boldermail-panel-wrap' );
			$( 'ul.boldermail-tabs li', panelWrap ).removeClass( 'active' );
			$( this ).parent().addClass( 'active' );
			$( '> div.boldermail-options-panel', panelWrap ).hide();

			// @see https://stackoverflow.com/a/43106210/1991500
			const panelSelector = $( this ).attr( 'href' );
			window.history.replaceState('', document.title, window.location.href.replace( location.hash, '' ) + panelSelector );
			$( panelSelector ).show();
		} );

		$( 'div.boldermail-panel-wrap' ).each( function() {
			const panelSelector = window.location.hash;
			$( this ).find( 'ul.boldermail-tabs li' ).eq( 0 ).find( 'a' ).click();

			if ( panelSelector ) {
				// If there is a hash present, click on the tab.
				$( this ).find( 'ul.boldermail-tabs li' ).find( 'a[href="' + panelSelector + '"]' ).click();
			} else {
				// Click on the first tab.
			}
		} );
	} ).trigger( 'boldermail-init-tabbed-panels' );

	/**
	 * Get confirmation before publishing newsletter.
	 *
	 * @since   1.0.0
	 */
	$( 'body.post-type-bm_newsletter #post' ).on( 'submit', function() {

		if ( boldermail.screenId !== 'bm_newsletter' ) {
			return true;
		}

		if ( $.inArray( boldermail.postStatus, ['publish', 'preparing', 'sending', 'sent'] ) !== -1 ) {
			return true;
		}

		const $btn = $( document.activeElement );

		if ( $btn.length && $( 'body.post-type-bm_newsletter #post' ).has( $btn ) && $btn.is( 'input[type="submit"]' ) && $btn.is( '[name="publish"]' ) ) {

			return confirm( wp.i18n.__( 'Are you sure your newsletter is ready to be sent? Have you double checked your design and list recipients? Once the newsletter starts sending, you will need to contact technical support to stop it.', 'boldermail' ) );

		}

	} );

	/**
	 * Get confirmation before deleting newsletter.
	 *
	 * @since   1.0.0
	 */
	$( 'body.post-type-bm_newsletter .submitdelete' ).on( 'click', function() {

		if ( boldermail.screenId !== 'bm_newsletter' && boldermail.screenId !== 'edit-bm_newsletter' ) {
			return true;
		}

		return confirm( wp.i18n.__( 'Are you sure you want to delete your newsletter? This action is irrevocable and will permanently remove your newsletter from your site. Please note that deleting the campaign will not stop your campaign from sending. To stop your campaign from sending, please contact technical support.', 'boldermail' ) );

	} );

	/**
	 * Activate the panel based on the error link in the admin notice.
	 *
	 * @since   1.0.0
	 */
	$( document ).on( 'click', '.boldermail-error-link', function( e ) {

		e.preventDefault();

		const href = $( this ).attr( 'href' );

		$( 'ul.boldermail-tabs li a[href=' + href + ']' ).click();

		$( 'html, body' ).animate( {
			scrollTop: $( '#boldermail-newsletter' ).offset().top
		} );

	} );

	/**
	 * Feed schedule form select fields.
	 *
	 * @since   1.0.0
	 */
	$( 'select[name="_when_to_send"]' ).bind( 'change', function () {
		const target = $( this ).val();
		const toggle = $( '#feed_panel .form-field[class*="show-if-"]' );

		toggle.hide();
		toggle.each( function() {
			if ( $( this ).hasClass( 'show-if-' + target ) ) {
				$( this ).show();
			}
		} );
	} ).trigger( 'change' );

	/**
	 * Toggle content based on input changes.
	 *
	 * @since   1.0.0
	 */
	const boldermail_hide_if = function() {
		$( '[data-boldermail-hide-if]' ).each( function() {

			var condition = $( this ).data( 'boldermail-hide-if' );

			if ( $( condition ).length > 0 ) {
				$( this ).hide();
			} else {
				$( this ).show();
			}

		} );
	};

	$( document.body ).on( 'change', '.boldermail-options-panel textarea, .boldermail-options-panel input, .boldermail-options-panel select', boldermail_hide_if );
	$( document.body ).on( 'boldermail-init-hide-if', boldermail_hide_if ).trigger( 'boldermail-init-hide-if' );

	/**
	 * Fill list information in newsletter "To:" tab.
	 *
	 * @since   1.0.0
	 */
	$( '#boldermail-newsletter #list_id' ).on( 'change', function() {
		const postId = $( 'input[name="post_ID"]' ).val();
		let listId = $( this ).val();
		listId = $.isArray( listId ) ? listId[ 0 ] : '';

		$.ajax( {
			type: 'post',
			dataType: 'json',
			url: boldermail.ajaxUrl,
			data: {
				action: 'boldermail_newsletter_list_data',
				nonce: boldermail.ajaxNonce,
				post: postId,
				list_id: listId,
			},
			success: function( response ) {
				if ( typeof response !== 'undefined' ) {
					if ( typeof response.from_name !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_from_name"]' ).val( response.from_name );
					}

					if ( typeof response.from_email !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_from_email"]' ).val( response.from_email );
					}

					if ( typeof response.reply_to !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_reply_to"]' ).val( response.reply_to );
					}

					if ( typeof response.company_name !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_company_name"]' ).val( response.company_name );
					}

					if ( typeof response.company_address !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_company_address"]' ).val( response.company_address );
					}

					if ( typeof response.permission !== 'undefined' ) {
						$( '#boldermail-newsletter textarea[name="_permission"]' ).val( response.permission );
					}
				}
			},
		} );
	} ).trigger( 'change' );

	/**
	 * Fill list information in autoresponder newsletter, and get trigger form.
	 *
	 * @since   1.0.0
	 */
	$( '#boldermail-newsletter select[name="_autoresponder"]' ).on( 'change', function() {
		const postId = $( 'input[name="post_ID"]' ).val();
		const autoresponder = $( this ).val();

		$.ajax( {
			type: 'post',
			dataType: 'json',
			url: boldermail.ajaxUrl,
			data: {
				action: 'boldermail_newsletter_ares_data',
				nonce: boldermail.ajaxNonce,
				post: postId,
				autoresponder: autoresponder,
			},
			success: function( response ) {
				if ( typeof response !== 'undefined' ) {
					if ( typeof response.from_name !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_from_name"]' ).val( response.from_name );
					}

					if ( typeof response.from_email !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_from_email"]' ).val( response.from_email );
					}

					if ( typeof response.reply_to !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_reply_to"]' ).val( response.reply_to );
					}

					if ( typeof response.company_name !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_company_name"]' ).val( response.company_name );
					}

					if ( typeof response.company_address !== 'undefined' ) {
						$( '#boldermail-newsletter input[name="_company_address"]' ).val( response.company_address );
					}

					if ( typeof response.permission !== 'undefined' ) {
						$( '#boldermail-newsletter textarea[name="_permission"]' ).val( response.permission );
					}
				}
			},
		} );

		$.ajax( {
			type: 'post',
			dataType: 'json',
			url: boldermail.ajaxUrl,
			data: {
				action: 'boldermail_newsletter_ares_trigger',
				nonce: boldermail.ajaxNonce,
				post_id: postId,
				autoresponder: autoresponder,
			},
			success: function( response ) {
				if ( typeof response !== 'undefined' ) {
					$( '#boldermail-newsletter #trigger_panel' ).replaceWith( response );
					$( '#boldermail-newsletter' ).find( 'ul.boldermail-tabs li.active' ).eq( 0 ).find( 'a' ).click();
					boldermail_hide_if();
				}
			},
		} );
	} ).trigger( 'change' );

	/**
	 * Disables the submit upload buttons when no data is entered.
	 *
	 * @see     wp-admin/js/common.js
	 * @since   1.7.0
	 * @return  void
	 */
	( function() {
		var button, input, form = $( 'form.boldermail-upload-form' );

		// exit when no upload form is found.
		if ( ! form.length )
			return;

		button = form.find( 'input[type="submit"]' );
		input = form.find( 'input[type="file"]' );

		/**
		 * Determines if any data is entered in any file upload input.
		 *
		 * @since  1.7.0
		 * @return {void}
		 */
		function toggleUploadButton() {

			// when no inputs have a value, disable the upload buttons.
			button.prop( 'disabled', '' === input.map( function() {
				return $( this ).val();
			} ).get().join( '' ) );

		}

		// update the status initially
		toggleUploadButton();

		// update the status when any file input changes
		input.on( 'change', toggleUploadButton );
	} )();

} )( jQuery );

/**
 * Emojis for subject line
 *
 * @see   boldermail_wp_emoji_text_input
 * @since 2.1.0
 */
wp.domReady( () => {
	const emojiPickerFields = document.querySelectorAll( '.emoji-picker-field');

	for ( let i = 0, len = emojiPickerFields.length; i < len; i++ ) {
		const emojiPickerField = emojiPickerFields[ i ];

		const emojiButton = emojiPickerField.querySelector( '.emoji-button' );
		const emojiContent = emojiPickerField.querySelector( '.emoji-contenteditable' );

		const inputText = emojiPickerField.querySelector( 'input[type="text"]' );
		inputText.style.display = 'none';

		// noinspection JSUnresolvedFunction EmojiButton class is included via `wp_enqueue_scripts`.
		const emojiPicker = new EmojiButton( {
			theme: 'auto',
			style: 'native',
			position: 'bottom-end',
		} );

		emojiPicker.on( 'emoji', function( emoji ) {
			emojiContent.insertAdjacentHTML( 'beforeend', emoji );
			emojiContent.dispatchEvent( new Event( 'keyup' ) );
		} );

		// @see https://stackoverflow.com/a/2885716/1991500
		[ 'propertychange', 'change', 'click', 'keyup', 'input', 'paste' ].forEach( function( e ) {
			emojiContent.addEventListener( e, function() {
				inputText.value = convertToText( this.innerHTML ); // Use innerHTML, not innerText to avoid errors with `&nbsp;`.
			} );
		} );

		emojiButton.addEventListener( 'click', function( e ) {
			e.preventDefault();

			// noinspection JSUnresolvedFunction EmojiButton class is included via `wp_enqueue_scripts`.
			emojiPicker.togglePicker( emojiButton );
		} );
	}
} );

/**
 * Convert `contenteditable` content to text.
 *
 * @see    https://gist.github.com/nathansmith/86b5d4b23ed968a92fd4
 * @since  2.1.0
 * @param  {string} str String to convert to text.
 * @return {string}     Sanitized text.
 */
const convertToText = ( str = '' ) => {
	// Ensure string.
	let value = String( str );

	// Convert encoding.
	value = value.replace( /&nbsp;/gi, ' ' );
	value = value.replace( /&amp;/gi, '&' );

	// Replace `<br>`.
	value = value.replace( /<br>/gi, '' );

	// Replace `<div>` (from Chrome).
	value = value.replace( /<div>/gi, '' );

	// Replace `<p>` (from IE).
	value = value.replace( /<p>/gi, '' );

	// Remove extra tags.
	value = value.replace( /<(.*?)>/g, '' );

	// Clean up spaces.
	value = value.replace( /[ ]+/g, ' ' );
	value = value.trim();

	// Expose string.
	return value;
};

/**
 * Prepend "Add New" buttons to template page.
 *
 * @since 2.2.0
 */
wp.domReady( () => {
	const button = document.querySelector( '.post-type-bm_template .page-title-action' );

	if ( ! button ) {
		return;
	}

	button.style.display = 'none';

	if ( boldermail.newTemplateLink.classicEditor && boldermail.newTemplateLink.blockEditor ) {
		const classicButton = document.createElement( 'a' );
		classicButton.className = 'page-title-action';
		classicButton.href = boldermail.newTemplateLink.classicEditor;
		classicButton.text = wp.i18n.__( 'Add New Classic Template', 'boldermail' );
		button.parentNode.insertBefore( classicButton, button );

		const blockButton = document.createElement( 'a' );
		blockButton.className = 'page-title-action';
		blockButton.href = boldermail.newTemplateLink.blockEditor;
		blockButton.text = wp.i18n.__( 'Add New Block Template', 'boldermail' );
		button.parentNode.insertBefore( blockButton, button );
	}
} );
