<?php
/**
 * Boldermail settings - Debug tab.
 *
 * @link       https://www.boldermail.com/about/
 * @since      1.7.0
 *
 * @package    Boldermail
 * @subpackage Boldermail/admin
 * @author     Hernan Villanueva <hernan@boldermail.com>
 */

defined( 'ABSPATH' ) || exit;

/**
 * Boldermail_Settings_Debug.
 *
 * @since   1.7.0
 */
class Boldermail_Settings_Debug extends Boldermail_Settings_Page {

	/**
	 * Constructor.
	 *
	 * @since   1.7.0
	 * @return  Boldermail_Settings_Debug
	 */
	public function __construct() {

		$this->id    = 'debug';
		$this->label = __( 'Debug', 'boldermail' );

		parent::__construct();

	}

	/**
	 * Get settings array.
	 *
	 * {@inheritDoc}
	 * @see     Boldermail_Settings_Page::get_settings()
	 * @since   1.7.0
	 * @return  array
	 */
	public function get_settings() {

		$settings = apply_filters(
			'boldermail_debug_settings',
			array(
				array(
					'title' => 'Debugging Options',
					'type'  => 'title',
					'desc'  => __( 'Display troubleshooting information on Boldermail admin pages.', 'boldermail' ),
					'id'    => 'debug_options',
				),

				array(
					'title'         => __( 'Debug', 'boldermail' ),
					'desc'          => __( 'Show additional information in admin notices and error messages', 'boldermail' ),
					'id'            => 'boldermail_show_debug',
					'default'       => 'no',
					'type'          => 'checkbox',
					'checkboxgroup' => 'start',
					'autoload'      => false,
				),

				array(
					'desc'          => __( 'Show hidden meta data', 'boldermail' ),
					'id'            => 'boldermail_show_hidden_meta',
					'default'       => 'no',
					'type'          => 'checkbox',
					'checkboxgroup' => 'end',
					'autoload'      => false,
				),

				array(
					'type' => 'sectionend',
					'id'   => 'debug_options',
				),
			)
		);

		return apply_filters( 'boldermail_get_settings_' . $this->id, $settings );

	}

	/**
	 * Output the settings.
	 *
	 * {@inheritDoc}
	 * @see     Boldermail_Settings_Page::output()
	 * @since   1.7.0
	 * @return  void
	 */
	public function output() {

		$settings = $this->get_settings();

		Boldermail_Settings::output_fields( $settings );

	}

	/**
	 * Save settings.
	 *
	 * {@inheritDoc}
	 * @see     Boldermail_Settings_Page::save()
	 * @since   1.7.0
	 * @return  void
	 */
	public function save() {

		$settings = $this->get_settings();

		Boldermail_Settings::save_fields( $settings );

	}

}

return new Boldermail_Settings_Debug();
