<?php
/**
 * Embed shortcode.
 *
 * @link       https://www.boldermail.com/about/
 * @since      1.2.0
 *
 * @package    Boldermail
 * @subpackage Boldermail/admin
 * @author     Hernan Villanueva <hernan@boldermail.com>
 */

defined( 'ABSPATH' ) || exit;

require_once BOLDERMAIL_PLUGIN_DIR . 'includes/shortcodes/class-boldermail-shortcode-youtube.php';
require_once BOLDERMAIL_PLUGIN_DIR . 'includes/shortcodes/class-boldermail-shortcode-vimeo.php';

/**
 * Boldermail_Shortcode_Embed class.
 *
 * @since   1.2.0
 */
class Boldermail_Shortcode_Embed {

	/**
	 * Do embed shortcode.
	 *
	 * @noinspection PhpUnusedParameterInspection
	 *
	 * @since   1.2.0
	 * @param   array  $atts    Shortcodes attributes.
	 * @param   string $url     URL content.
	 * @return  string
	 */
	public static function do_shortcode( $atts, $url = '' ) { /* phpcs:ignore Generic.CodeAnalysis.UnusedFunctionParameter.FoundBeforeLastUsed */

		if ( empty( $url ) && ! empty( $attr['src'] ) ) {
			$url = $attr['src'];
		}

		if ( empty( $url ) ) {
			return '';
		}

		$youtube_regex = '/^((?:https?:)?\/\/)?((?:www|m)\.)?((?:youtube\.com|youtu.be))(\/(?:[\w\-]+\?v=|embed\/|v\/)?)([\w\-]+)(\S+)?$/';
		$is_youtube    = preg_match( $youtube_regex, $url );

		$vimeo_regex = '/(https?:\/\/)?(www\.)?(player\.)?vimeo\.com\/([a-z]*\/)*([‌​0-9]{6,11})[?]?.*/';
		$is_vimeo    = preg_match( $vimeo_regex, $url );

		$video_atts[0] = $url;

		if ( $is_youtube ) {
			return Boldermail_Shortcode_YouTube::do_shortcode( $video_atts );
		}

		if ( $is_vimeo ) {
			return Boldermail_Shortcode_Vimeo::do_shortcode( $video_atts );
		}

		/**
		 * Should we return the original URL or an empty string?
		 * Returning message for now.
		 *
		 * @since 1.2.0
		 */
		return '<!--Boldermail Embed Error: Service not supported-->';

	}

}
