<?php
/**
 * Vimeo shortcode.
 *
 * @link       https://www.boldermail.com/about/
 * @since      1.2.0
 *
 * @package    Boldermail
 * @subpackage Boldermail/admin
 * @author     Hernan Villanueva <hernan@boldermail.com>
 */

defined( 'ABSPATH' ) || exit;

require_once BOLDERMAIL_PLUGIN_DIR . 'includes/tools/class-boldermail-image-editor.php';

/**
 * Boldermail_Shortcode_Vimeo class.
 *
 * @since   1.2.0
 */
class Boldermail_Shortcode_Vimeo {

	/**
	 * Vimeo shortcode.
	 *
	 * @see     wp-content/plugins/jetpack/modules/shortcodes/vimeo.php
	 * @since   1.2.0
	 * @param   array $atts Shortcode attributes.
	 * @return  string
	 */
	public static function do_shortcode( $atts ) {

		$attr = array_map(
			'intval',
			shortcode_atts(
				array(
					'id'       => 0,
					'width'    => 0,
					'height'   => 0,
					'autoplay' => 0,
					'loop'     => 0,
				),
				$atts
			)
		);

		if ( isset( $atts[0] ) ) {
			$attr['id'] = jetpack_shortcode_get_vimeo_id( $atts );
		}

		if ( ! $attr['id'] ) {
			return '<!-- vimeo error: not a vimeo video -->';
		}

		$url = esc_url( 'https://vimeo.com/' . $attr['id'] );

		$thumbnail = self::get_thumbnail( $attr['id'] );

		if ( $thumbnail ) {
			return '<span class="embed-vimeo" style="text-align: center; display: block;"><a href="' . esc_url( $url ) . '" target="_blank" rel="noopener">' . $thumbnail . '</a></span>';
		}

		return '';

	}

	/**
	 * Get the Vimeo video thumbnail HTML from the Vimeo video ID.
	 *
	 * @since   1.0.0
	 * @param   string $id  Vimeo video ID.
	 * @return  string
	 */
	public static function get_thumbnail( $id ) {

		$post = get_post();

		$thumbnail_id  = '';
		$thumbnail_src = '';

		if ( $post ) {
			$thumbnail_id = get_post_meta( $post->ID, "_vimeo_thumbnail_$id", true );
		}

		if ( $thumbnail_id ) {
			$thumbnail_src = wp_get_attachment_image_src( $thumbnail_id, 'boldermail_newsletter' );
		}

		// If the image was never created before, or if it vanished...
		if ( ! $thumbnail_id || ! $thumbnail_src ) {
			$thumbnail_src = self::get_thumbnail_url( $id );
			$thumbnail_src = Boldermail_Image_Editor::add_video_watermark( $thumbnail_src );

			/**
			 * Insert base64 image into WordPress uploads directory.
			 *
			 * @see     Boldermail_Image_Editor::add_video_watermark
			 *          The function returns a base64 encoded JPEG image.
			 * @since   1.2.0
			 */
			$attachment_id = Boldermail_Image_Editor::insert_base64_attachment( $thumbnail_src, BOLDERMAIL_PREFIX . "_vimeo_thumbnail_$id.jpeg" );

			if ( $attachment_id ) {
				update_post_meta( $post->ID, "_vimeo_thumbnail_$id", $attachment_id );
				$thumbnail_src = wp_get_attachment_image_src( $attachment_id, 'boldermail_newsletter' );
			} else {
				$thumbnail_src = false;
			}
		}

		return ( $thumbnail_src ) ? '<img src="' . esc_url( $thumbnail_src[0] ) . '" alt="Vimeo video" width="' . esc_attr( $thumbnail_src[1] ) . '" height="' . esc_attr( $thumbnail_src[2] ) . '" />' : false;

	}

	/**
	 * Get the Vimeo video thumbnail URL from the Vimeo video ID.
	 *
	 * @since   1.0.0
	 * @param   string $id  Vimeo video ID.
	 * @return  string
	 */
	public static function get_thumbnail_url( $id ) {

		$vimeo_json = json_decode( file_get_contents( "https://vimeo.com/api/oembed.json?url=https://vimeo.com/{$id}&height=540" ) ); /* phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents */

		return $vimeo_json->thumbnail_url;

	}

}
