<?php
/**
 * "From:" meta box panel.
 *
 * @link       https://www.boldermail.com/about/
 * @since      1.0.0
 *
 * @package    Boldermail
 * @subpackage Boldermail/admin
 * @author     Hernan Villanueva <hernan@boldermail.com>
 */

defined( 'ABSPATH' ) || exit;

?>
<div id="from_panel" class="panel boldermail-options-panel">

	<h3><?php esc_html_e( 'Who is sending this campaign?', 'boldermail' ); ?></h3>

	<p class="form-field">
		<label for="from_name"><?php esc_html_e( 'From name', 'boldermail' ); ?></label>
		<input type="text" <?php echo esc_attr( $readonly ); ?> id="from_name" name="_from_name" value="<?php echo esc_attr( $newsletter->get_from_name() ); ?>" class="regular-text" />
		<?php echo boldermail_help_tip( esc_html__( 'Use a name your subscribers will instantly recognize, like your company name.', 'boldermail' ) ); ?>
	</p>

	<p class="form-field">
		<label for="from_email"><?php esc_html_e( 'From email', 'boldermail' ); ?></label>
		<input type="email" <?php echo esc_attr( $readonly ); ?> id="from_email" name="_from_email" value="<?php echo esc_attr( $newsletter->get_from_email() ); ?>" class="regular-text" />
		<?php echo boldermail_help_tip( esc_html__( 'Your email address must match the email address associated with your Boldermail account.', 'boldermail' ) ); ?>
	</p>

	<p class="form-field">
		<label for="reply_to"><?php esc_html_e( 'Reply to', 'boldermail' ); ?></label>
		<input type="email" <?php echo esc_attr( $readonly ); ?> id="reply_to" name="_reply_to" value="<?php echo esc_attr( $newsletter->get_reply_to() ); ?>" class="regular-text" />
		<?php echo boldermail_help_tip( wp_kses_post( 'Where should the replies to your campaign email be sent? You can use the same email as in the <code>From email</code> field.', 'boldermail' ) ); ?>
	</p>

	<p class="form-field">
		<label for="company_name"><?php esc_html_e( 'Company Name', 'boldermail' ); ?></label>
		<input type="text" <?php echo esc_attr( $readonly ); ?> id="company_name" name="_company_name" value="<?php echo esc_attr( $newsletter->get_company_name() ); ?>" class="regular-text" />
		<?php echo boldermail_help_tip( esc_html__( 'Your company/organization name.', 'boldermail' ) ); ?>
	</p>

	<p class="form-field">
		<label for="company_address"><?php esc_html_e( 'Company Address', 'boldermail' ); ?></label>
		<input type="text" <?php echo esc_attr( $readonly ); ?> id="company_address" name="_company_address" value="<?php echo esc_attr( $newsletter->get_company_address() ); ?>" class="regular-text" />
		<?php echo boldermail_help_tip( esc_html__( 'Your company/organization address.', 'boldermail' ) ); ?>
	</p>

	<fieldset class="form-field">
		<label for="permission"><?php esc_html_e( 'Permission Reminder', 'boldermail' ); ?></label>
		<textarea <?php echo esc_attr( $readonly ); ?> id="permission" name="_permission" class="large-text" rows="3"><?php echo esc_textarea( $newsletter->get_permission() ); ?></textarea>
		<?php echo boldermail_help_tip( wp_kses_post( __( 'Explain to your users why they are receiving this email (e.g. <i>&quot;You are receiving this email because you opted in on our signup form in The Postman&#39;s Knock blog (www.thepostmansknock.com)&quot;</i>).', 'boldermail' ) ) ); ?>
	</fieldset>

</div>
<?php
